## ----setup, echo=FALSE, results="hide"----------------------------------------
knitr::opts_chunk$set(
    tidy = FALSE, cache = TRUE,
    dev = "png",
    message = TRUE, error = FALSE, warning = TRUE
)

## ----Bioconductor_installation, eval=FALSE------------------------------------
#  if (!requireNamespace("BiocManager", quietly = TRUE)) {
#      install.packages("BiocManager")
#  }
#  BiocManager::install("IsoBayes")

## ----vignettes, eval=FALSE----------------------------------------------------
#  browseVignettes("IsoBayes")

## ----citation-----------------------------------------------------------------
citation("IsoBayes")

## ----load, message=FALSE------------------------------------------------------
library(IsoBayes)

## ----specify extdata path-----------------------------------------------------
data_dir = system.file("extdata", package = "IsoBayes")

## ----set path MM psm----------------------------------------------------------
path_to_peptides_psm = paste0(data_dir, "/AllPeptides.psmtsv")

## ----set path mRNA------------------------------------------------------------
tpm_path = paste0(data_dir, "/jurkat_isoform_kallisto.tsv")

## ----load psm-----------------------------------------------------------------
PSM_data_loaded = load_data(
    path_to_peptides_psm = path_to_peptides_psm,
    path_to_tpm = tpm_path
)

## ----set path MM intensities--------------------------------------------------
path_to_peptides_intensities = paste0(data_dir, "/AllQuantifiedPeptides.tsv")
data_loaded = load_data(
    path_to_peptides_psm = path_to_peptides_psm,
    path_to_peptides_intensities = path_to_peptides_intensities,
    abundance_type = "intensities",
    path_to_tpm = tpm_path
)

## ----set path OpenMS, eval = FALSE--------------------------------------------
#  Percolator_data_loaded = load_data(
#      path_to_peptides_psm = "/path/to/file.idXML",
#      input_type = "openMS",
#      path_to_tpm = tpm_path
#  )

## ----set user data, eval = FALSE----------------------------------------------
#  # X can be a path to a .tsv file, a data.frame or a SummarizedExperiment object
#  user_data_loaded = load_data(
#      path_to_peptides_psm = X,
#      input_type = "other",
#      path_to_tpm = tpm_path
#  )

## ----inference, eval = FALSE--------------------------------------------------
#  set.seed(169612)
#  results = inference(data_loaded)

## ----default inference--------------------------------------------------------
path_to_map_iso_gene = paste0(data_dir, "/map_iso_gene.csv")
set.seed(169612)
results_normalized = inference(data_loaded, map_iso_gene = path_to_map_iso_gene)

## ----get res------------------------------------------------------------------
names(results_normalized)

## ----get iso res--------------------------------------------------------------
head(results_normalized$isoform_results)

## ----get iso res norm---------------------------------------------------------
head(results_normalized$normalized_isoform_results)

## ----get iso res norm gene----------------------------------------------------
head(results_normalized$gene_abundance)

## ----plotting results---------------------------------------------------------
plot_relative_abundances(results_normalized, gene_id = "TUBB")

## ----plotting results no normalization----------------------------------------
plot_relative_abundances(results_normalized, gene_id = "TUBB", normalize_gene = FALSE)

## ----sessionInfo--------------------------------------------------------------
sessionInfo()

